.. _wrap-up:

========================================
Wrap-up and Acknowledgements
========================================

I hope this library will be useful for minority I belong to. If you have some ideas for testing that you'd like to use with Django (like Windmill integration), don't hesistate to write me (bugs at almad.net), so I know what is wanted (and used) and hopefully, you'll se it implemented.

At last, but not at least, I'd like to send thanks & kudos to:

* `Mikeal Rogers <http://www.mikealrogers.com/>`_ for a lot of ideas and implementation. Lot of his code is reused in this library (see attributions in code)
* `CherryPy team <http://cherrypy.org/wiki/CherryPyTeam>`_ for their excellent WSGI implementation (and nice framework)
* `Jason Pellerin <http://somethingaboutorange.com/mrl/>`_ for `nose <http://somethingaboutorange.com/mrl/projects/nose/>`_ library we're building on
* Django authors and contributors for `Django <http://www.djangoproject.com/>`_ itself



